@@ -16,7 +16,7 @@ from os import path as op  # pragma: no cover
 
 from _pytest import python
 
-from pytest_bdd.feature import Feature  # pragma: no cover
+from pytest_bdd.feature import Feature, force_encode  # pragma: no cover
 from pytest_bdd.steps import recreate_function, get_caller_module
 from pytest_bdd.types import GIVEN
 
@@ -37,7 +37,7 @@ class GivenAlreadyUsed(Exception):  # pragma: no cover
     """Fixture that implements the Given has been already used."""
 
 
-def _find_step_function(request, name):
+def _find_step_function(request, name, encoding):
     """Match the step defined by the regular expression pattern.
 
     :param request: PyTest request object.
@@ -46,8 +46,9 @@ def _find_step_function(request, name):
     :return: Step function.
 
     """
+
     try:
-        return request.getfuncargvalue(name)
+        return request.getfuncargvalue(force_encode(name, encoding))
     except python.FixtureLookupError:
 
         for fixturename, fixturedefs in request._fixturemanager._arg2fixturedefs.items():
@@ -73,7 +74,7 @@ def _find_step_function(request, name):
         raise
 
 
-def scenario(feature_name, scenario_name):
+def scenario(feature_name, scenario_name, encoding='utf-8'):
     """Scenario. May be called both as decorator and as just normal function."""
 
     caller_module = get_caller_module()
@@ -84,7 +85,7 @@ def scenario(feature_name, scenario_name):
             # Get the feature
             base_path = request.getfuncargvalue('pytestbdd_feature_base_dir')
             feature_path = op.abspath(op.join(base_path, feature_name))
-            feature = Feature.get_feature(feature_path)
+            feature = Feature.get_feature(feature_path, encoding=encoding)
 
             # Get the scenario
             try:
@@ -107,7 +108,7 @@ def scenario(feature_name, scenario_name):
             givens = set()
             # Execute scenario steps
             for step in scenario.steps:
-                step_func = _find_step_function(request, step.name)
+                step_func = _find_step_function(request, step.name, encoding=encoding)
 
                 # Check the step types are called in the correct order
                 if step_func.step_type != step.type:
@@ -146,6 +147,4 @@ def scenario(feature_name, scenario_name):
 
         return _scenario
 
-    recreate_function(decorator, module=caller_module)
-
     return decorator
